package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.IntegralCateMapper;
import com.ruoyi.system.domain.IntegralCate;
import com.ruoyi.system.service.IIntegralCateService;

/**
 * 积分商品分类Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@Service
public class IntegralCateServiceImpl implements IIntegralCateService 
{
    @Autowired
    private IntegralCateMapper integralCateMapper;

    /**
     * 查询积分商品分类
     * 
     * @param id 积分商品分类主键
     * @return 积分商品分类
     */
    @Override
    public IntegralCate selectIntegralCateById(Long id)
    {
        return integralCateMapper.selectIntegralCateById(id);
    }

    /**
     * 查询积分商品分类列表
     * 
     * @param integralCate 积分商品分类
     * @return 积分商品分类
     */
    @Override
    public List<IntegralCate> selectIntegralCateList(IntegralCate integralCate)
    {
        return integralCateMapper.selectIntegralCateList(integralCate);
    }

    /**
     * 新增积分商品分类
     * 
     * @param integralCate 积分商品分类
     * @return 结果
     */
    @Override
    public int insertIntegralCate(IntegralCate integralCate)
    {
        return integralCateMapper.insertIntegralCate(integralCate);
    }

    /**
     * 修改积分商品分类
     * 
     * @param integralCate 积分商品分类
     * @return 结果
     */
    @Override
    public int updateIntegralCate(IntegralCate integralCate)
    {
        return integralCateMapper.updateIntegralCate(integralCate);
    }

    /**
     * 批量删除积分商品分类
     * 
     * @param ids 需要删除的积分商品分类主键
     * @return 结果
     */
    @Override
    public int deleteIntegralCateByIds(Long[] ids)
    {
        return integralCateMapper.deleteIntegralCateByIds(ids);
    }

    /**
     * 删除积分商品分类信息
     * 
     * @param id 积分商品分类主键
     * @return 结果
     */
    @Override
    public int deleteIntegralCateById(Long id)
    {
        return integralCateMapper.deleteIntegralCateById(id);
    }
}
